DroplessArena

Struct DroplessArena 

pub struct DroplessArena<'arena> {
    _lives: PhantomData<&'arena u8>,
    chunks: RefCell<Vec<ArenaChunk<u8>>>,
    head: Cell<*mut u8>,
    tail: Cell<*mut u8>,
}

Fields

_lives: PhantomData<&'arena u8>chunks: RefCell<Vec<ArenaChunk<u8>>>head: Cell<*mut u8>tail: Cell<*mut u8>

Implementations



impl<'arena> DroplessArena<'arena>

pub const fn new() -> DroplessArena<'arena>

pub fn alloc<T>(&'arena self, value: T) -> &'arena mut T

Allocates a T in the DroplessArena, and returns a mutable reference to it.

Panics
  • Panics if T implements Drop
  • Panics if T is zero-sized

pub fn alloc_slice<T>(&'arena self, slice: &[T]) -> &'arena mut [T]
where T: Copy,

Allocates a slice of Ts`, copied from the given slice, returning a mutable reference to it.

Panics
  • Panics if T implements Drop
  • Panics if T is zero-sized
  • Panics if the slice is empty

pub fn alloc_str(&'arena self, string: &str) -> &'arena str

Allocates a copy of the given &str, returning a reference to the allocation.

Panics

Panics if the string is empty.

pub fn alloc_raw(&'arena self, layout: Layout) -> *mut u8

Allocates some bytes based on the given Layout.

Panics

Panics if the provided Layout has size 0

pub fn contains_slice<T>(&self, slice: &[T]) -> bool

Checks whether the given slice is allocated in this arena